class WriterUnknownFileFormat(Exception):
    """Raises when user specified an unknown output file format."""
    pass


__all__ = [
    'WriterUnknownFileFormat',
]
